aboutsummaryrefslogtreecommitdiffstats
path: root/examples/widgets/richtext/textobject/textobject.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/widgets/richtext/textobject/textobject.py')
-rw-r--r--examples/widgets/richtext/textobject/textobject.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/widgets/richtext/textobject/textobject.py b/examples/widgets/richtext/textobject/textobject.py
index b828ea3d0..60abfc19c 100644
--- a/examples/widgets/richtext/textobject/textobject.py
+++ b/examples/widgets/richtext/textobject/textobject.py
@@ -40,9 +40,9 @@
##
#############################################################################
-"""PySide2 port of the widgets/richtext/textobject example from Qt v5.x"""
+"""PySide6 port of the widgets/richtext/textobject example from Qt v5.x"""
-from PySide2 import QtCore, QtGui, QtWidgets, QtSvg
+from PySide6 import QtCore, QtGui, QtWidgets, QtSvg
class SvgTextObject(QtCore.QObject, QtGui.QTextObjectInterface):